#! /bin/sh

# Convert the examples and generate a example.json file to use with the web interface
# Based on the dataset used in the Floraverse Character Generator of feuforeve.fr

# Output directory
mkdir -p output

# Convert csv to phonology files
./py-phonagen/phonology-csv2json.py ./examples/byakjakiq.csv --id byakjakiq --main byakjakiq --description "Byakjakiq phonology" --output ./output/phonology-byakjakiq.json
./py-phonagen/phonology-csv2json.py ./examples/citrican.csv --id citrican --main citrican --description "Citrican phonology" --output ./output/phonology-citrican.json
./py-phonagen/phonology-csv2json.py ./examples/gloamish.csv --id gloamish --main gloamish --description "Gloamish phonology" --output ./output/phonology-gloamish.json
./py-phonagen/phonology-csv2json.py ./examples/mewyorkish.csv --id mewyorkish --main mewyorkish --description "Mewyorkish phonology" --output ./output/phonology-mewyorkish.json
./py-phonagen/phonology-csv2json.py ./examples/pelirish.csv --id pelirish --main pelirish --description "Pelirish phonology" --output ./output/phonology-pelirish.json
./py-phonagen/phonology-csv2json.py ./examples/polarian.csv --id polarian --main polarian --description "Polarian phonology" --output ./output/phonology-polarian.json

# Convert examples lists to chain generators
./py-phonagen/generator-list2chain.py ./examples/byakjakiq.list --id byakjakiq-chain --description "Byakjakiq (imaginary language using Hangul, Markov chain generator)" --phonology byakjakiq --phonologyfile ./output/phonology-byakjakiq.json --order 3 --output ./output/generator-chain-byakjakiq.json
./py-phonagen/generator-list2chain.py ./examples/citrican.list --id citrican-chain --description "Citrican (Spanish-based, Markov chain generator)" --phonology citrican --phonologyfile ./output/phonology-citrican.json --order 3 --output ./output/generator-chain-citrican.json
./py-phonagen/generator-list2chain.py ./examples/gloamish.list --id gloamish-chain --description "Gloamish (imaginary language using Armenian alphabet, Markov chain generator)" --phonology gloamish --phonologyfile ./output/phonology-gloamish.json --order 2 --output ./output/generator-chain-gloamish.json
./py-phonagen/generator-list2chain.py ./examples/mewyorkish.list --id mewyorkish-chain --description "Mewyorkish (English-based, Markov chain generator)" --phonology mewyorkish --phonologyfile ./output/phonology-mewyorkish.json --order 2 --output ./output/generator-chain-mewyorkish.json
./py-phonagen/generator-list2chain.py ./examples/pelirish.list --id pelirish-chain --description "Pelirish (Russian-based, Markov chain generator)" --phonology pelirish --phonologyfile ./output/phonology-pelirish.json --order 3 --output ./output/generator-chain-pelirish.json
./py-phonagen/generator-list2chain.py ./examples/polarian.list --id polarian-chain --description "Polarian (Portuguese-based, Markov chain generator)" --phonology polarian --phonologyfile ./output/phonology-polarian.json --order 3 --output ./output/generator-chain-polarian.json

# Convert examples lists to rule generators
./py-phonagen/generator-list2rule.py ./examples/byakjakiq.list --id byakjakiq-rule --description "Byakjakiq (imaginary language using Hangul, rule generator)" --phonology byakjakiq --phonologyfile ./output/phonology-byakjakiq.json --output ./output/generator-rule-byakjakiq.json
./py-phonagen/generator-list2rule.py ./examples/citrican.list --id citrican-rule --description "Citrican (Spanish-based, rule generator)" --phonology citrican --phonologyfile ./output/phonology-citrican.json --output ./output/generator-rule-citrican.json
./py-phonagen/generator-list2rule.py ./examples/gloamish.list --id gloamish-rule --description "Gloamish (imaginary language using Armenian alphabet, rule generator)" --phonology gloamish --phonologyfile ./output/phonology-gloamish.json --output ./output/generator-rule-gloamish.json
./py-phonagen/generator-list2rule.py ./examples/mewyorkish.list --id mewyorkish-rule --description "Mewyorkish (English-based, rule generator)" --phonology mewyorkish --phonologyfile ./output/phonology-mewyorkish.json --output ./output/generator-rule-mewyorkish.json
./py-phonagen/generator-list2rule.py ./examples/pelirish.list --id pelirish-rule --description "Pelirish (Russian-based, rule generator)" --phonology pelirish --phonologyfile ./output/phonology-pelirish.json --output ./output/generator-rule-pelirish.json
./py-phonagen/generator-list2rule.py ./examples/polarian.list --id polarian-rule --description "Polarian (Portuguese-based, rule generator)" --phonology polarian --phonologyfile ./output/phonology-polarian.json --output ./output/generator-rule-polarian.json

# Merge everything into a single file
./py-phonagen/phonagen-merge.py ./output/generator-* --output ./output/phonagen-example.json

# Copy the generated file into the web directory
cp ./output/phonagen-example.json ./web/
